==> gitlab-foss-v18.4.3.tar.bz2: gitlab-foss-v18.4.3/spec/frontend/repository/file_tree_browser/index_spec.js <==
import { setActivePinia } from 'pinia';
import { nextTick } from 'vue';
import { resetHTMLFixture, setHTMLFixture } from 'helpers/fixtures';
import initFileTreeBrowser from '~/repository/file_tree_browser/index';
import { useFileTreeBrowserVisibility } from '~/repository/stores/file_tree_browser_visibility';
import { useViewport } from '~/pinia/global_stores/viewport';
import { pinia } from '~/pinia/instance';
import createRouter from '~/repository/router';
import createMockApollo from 'helpers/mock_apollo_helper';

jest.mock('~/repository/file_tree_browser/file_tree_browser.vue', () => ({
  props: jest.requireActual('~/repository/file_tree_browser/file_tree_browser.vue').default.props,
  render(h) {
    return h('div', {
      attrs: {
        'data-file-tree-browser-component': true,
        'data-project-path': this.projectPath,
        'data-current-ref': this.currentRef,
        'data-ref-type': this.refType,
      },
    });
  },
}));

describe('initFileTreeBrowser', () => {
  const getFileTreeBrowserComponent = () =>
    document.querySelector('[data-file-tree-browser-component]');

  beforeEach(() => {
    setActivePinia(pinia);
    useViewport().reset();
    useFileTreeBrowserVisibility().$reset();

    setHTMLFixture('<div id="js-file-browser"></div>');
  });

  afterEach(() => {
    resetHTMLFixture();
  });

  describe.each`
    routeName            | isCompactViewport | fileTreeVisible | expectedVisible
    ${'blobPathDecoded'} | ${false}          | ${true}         | ${true}
    ${'blobPathDecoded'} | ${true}           | ${true}         | ${false}
    ${'blobPathDecoded'} | ${false}          | ${false}        | ${false}
    ${'projectRoot'}     | ${true}           | ${false}        | ${false}
  `(
    'visibility logic when route is $routeName, compact screen: $isCompactViewport, file tree visible: $fileTreeVisible',
    ({ routeName, isCompactViewport, fileTreeVisible, expectedVisible }) => {
      beforeEach(() => {
        useViewport().updateIsCompact(isCompactViewport);
        useFileTreeBrowserVisibility().setFileTreeVisibility(fileTreeVisible);
      });

      it(`${expectedVisible ? 'shows' : 'hides'} file tree browser`, async () => {
        const apolloProvider = createMockApollo([]);

        const options = {
          projectPath: 'gitlab-org/gitlab',
          ref: 'main',
          refType: 'heads',
        };

        const router = createRouter();
        await router.push({ name: routeName });

        await initFileTreeBrowser(router, options, apolloProvider);
        await nextTick();

        const component = getFileTreeBrowserComponent();

        if (expectedVisible) {
          expect(component.dataset).toMatchObject({
            projectPath: options.projectPath,
            currentRef: options.ref,
            refType: options.refType,
          });
        } else {
          expect(component).toBeNull();
        }
      });
    },
  );
});

==> gitlab-foss-v18.7.0.tar.bz2: gitlab-foss-v18.7.0/spec/frontend/repository/file_tree_browser/index_spec.js <==
import { setActivePinia } from 'pinia';
import { nextTick } from 'vue';
import { resetHTMLFixture, setHTMLFixture } from 'helpers/fixtures';
import initFileTreeBrowser from '~/repository/file_tree_browser/index';
import { useMainContainer } from '~/pinia/global_stores/main_container';
import { pinia } from '~/pinia/instance';
import createRouter from '~/repository/router';
import createMockApollo from 'helpers/mock_apollo_helper';

jest.mock('~/repository/file_tree_browser/file_tree_browser.vue', () => ({
  props: jest.requireActual('~/repository/file_tree_browser/file_tree_browser.vue').default.props,
  render(h) {
    return h('div', {
      attrs: {
        'data-file-tree-browser-component': true,
        'data-project-path': this.projectPath,
        'data-current-ref': this.currentRef,
        'data-ref-type': this.refType,
      },
    });
  },
}));

jest.mock('~/pinia/global_stores/main_container', () => ({ useMainContainer: jest.fn() }));

describe('initFileTreeBrowser', () => {
  let mockMainContainerStore;
  const getFileTreeBrowserComponent = () =>
    document.querySelector('[data-file-tree-browser-component]');

  beforeEach(() => {
    setActivePinia(pinia);
    setHTMLFixture('<div id="js-file-browser"></div>');
    mockMainContainerStore = {
      isCompact: false,
      isIntermediate: false,
      isWide: true,
    };

    useMainContainer.mockReturnValue(mockMainContainerStore);
  });

  afterEach(() => {
    resetHTMLFixture();
  });

  describe.each`
    routeName            | isCompactSize | expectedVisible
    ${'blobPathDecoded'} | ${true}       | ${false}
    ${'blobPathDecoded'} | ${false}      | ${true}
    ${'projectRoot'}     | ${false}      | ${false}
  `(
    'visibility logic when route is $routeName, compact screen: $isCompactSize',
    ({ routeName, isCompactSize, expectedVisible }) => {
      it(`${expectedVisible ? 'shows' : 'hides'} file tree browser`, async () => {
        mockMainContainerStore.isCompact = isCompactSize;
        const apolloProvider = createMockApollo([]);

        const options = {
          projectPath: 'gitlab-org/gitlab',
          ref: 'main',
          refType: 'heads',
        };

        const router = createRouter();
        await router.push({ name: routeName });

        await initFileTreeBrowser(router, options, apolloProvider);
        await nextTick();

        const component = getFileTreeBrowserComponent();

        if (expectedVisible) {
          expect(component.dataset).toMatchObject({
            projectPath: options.projectPath,
            currentRef: options.ref,
            refType: options.refType,
          });
        } else {
          expect(component).toBeNull();
        }
      });
    },
  );
});
